get_alt_block

Function get_alt_block 

pub fn get_alt_block(
    db: &BlockchainDatabase,
    alt_block_height: &AltBlockHeight,
    tx_ro: &Snapshot,
) -> DbResult<Block>
Retrieve an alt [Block] via its AltBlockHeight.

This function will look at only the blocks with the given AltBlockHeight::chain_id, no others even if they are technically part of this chain.