get_alt_block_information

Function get_alt_block_information 

pub fn get_alt_block_information(
    db: &BlockchainDatabase,
    alt_block_height: &AltBlockHeight,
    tx_ro: &Snapshot,
) -> DbResult<AltBlockInformation>
Retrieves an [AltBlockInformation] from the database.

This function will look at only the blocks with the given AltBlockHeight::chain_id, no others even if they are technically part of this chain.