pub fn get_alt_block_extended_header_from_height(
db: &BlockchainDatabase,
height: &AltBlockHeight,
tx_ro: &Snapshot,
) -> DbResult<ExtendedBlockHeader>Expand description
Retrieves the [ExtendedBlockHeader] of the alt-block with an exact AltBlockHeight.
This function will look at only the blocks with the given AltBlockHeight::chain_id, no others
even if they are technically part of this chain.