pub fn get_alt_block_hash(
db: &BlockchainDatabase,
block_height: &BlockHeight,
alt_chain: ChainId,
tx_ro: &Snapshot,
tapes: &impl TapesRead,
) -> DbResult<BlockHash>Expand description
Retrieves the hash of the block at the given block_height on the alt chain with
the given [ChainId].
This function will get blocks from the whole chain, for example if you were to ask for height
0 with any [ChainId] (as long that chain actually exists) you will get the main chain genesis.