pub fn get_alt_chain_history_ranges(
db: &BlockchainDatabase,
range: Range<BlockHeight>,
alt_chain: ChainId,
tx_ro: &Snapshot,
) -> DbResult<Vec<(Chain, Range<BlockHeight>)>>Expand description
Get the height history of an alt-chain in reverse chronological order.
Height history is a list of height ranges with the corresponding [Chain] they are stored under.
For example if your range goes from height 0 the last entry in the list will be [Chain::Main]
upto the height where the first split occurs.